# Depression Library

This is a Python package designed to analyze the results of a depression test and provide a severity level based on the answers.

## Installation

You can install My Depression Library using pip:

```bash
pip install -i https://test.pypi.org/simple/depression_library